@@ -73,14 +73,13 @@ prepare.args <- function(data, ...) UseMethod("prepare.args")
 #' @return a sgldata object with the covariates reordered
 #' @author Martin Vincent
 #' @method rearrange sgldata
-#' @S3method rearrange sgldata
 #' @export
 #' @family sgldata
 rearrange.sgldata <- function(data, covariate.order, ...) 
 {
 	
-	data$x <- data$x[,covariate.order]
-	data$covariate.names <- data$covarite.names[covariate.order]
+	data$X <- data$X[,covariate.order, drop = FALSE]
+	data$covariate.names <- data$covariate.names[covariate.order]
 	
 	return(data)
 }
@@ -96,65 +95,81 @@ rearrange.sgldata <- function(data, covariate.order, ...)
 #' @param sampleGrouping grouping of samples, a factor of length \eqn{N} (will be parsed to the loss module as \code{G}). Default is no grouping (NULL), that is all samples is the same group.
 #' @param group.names a vector with the names of the parameter groups (the length must equal the number of rows in the \eqn{\beta} matrix). 
 #' @param sparseX if TRUE \code{x} will be treated as sparse, if FALSE \code{x} will be treated as dens.
+#' @param sparseY if TRUE \code{y} will be treated as sparse, if FALSE \code{y} will be treated as dens.
 #' @author Martin Vincent
+#' @importFrom methods is
+#' @importFrom methods as
 #' @export
 #' @family sgldata
-create.sgldata <- function(x, y, weights = rep(1/nrow(x), nrow(x)), sampleGrouping = NULL, group.names = NULL, sparseX = is(x, "sparseMatrix")) {
+create.sgldata <- function(x, y, weights = NULL, sampleGrouping = NULL, group.names = NULL, sparseX = is(x, "sparseMatrix"), sparseY = is(y, "sparseMatrix")) {
 	
 	#TODO dim checks
 	
+	### Data 
 	data <- list()
 	
-	# Is X sparse
+	### Dimensions 
+	data$n.covariate <- ncol(x)
+	data$n.samples <- nrow(x)		
+	
+	### X data
 	data$sparseX <- sparseX
 
 	if(data$sparseX) {
 		data$X <- as(x, "CsparseMatrix")
-	} else {
+	} else if(is(x, "matrix") || is(x, "sparseMatrix")){
 		data$X <- as.matrix(x)
+	} else {
+		stop("design matrix of unkown type")
 	}
 
+	# Dim-names
+	data$sample.names <- rownames(x)
+	data$covariate.names <- colnames(x)
+	
+	### Y data
+	data$sparseY <- sparseY
+		
 	if(is.null(y)) {
 		data$Y <- NULL
 	} else if(is.vector(y)) {
 		data$Y <- as.numeric(y)
 	} else if(is.matrix(y)) {
 		data$Y <- apply(y, 2, as.numeric)
+	} else if(sparseY) {
+		data$Y <- as(y, "CsparseMatrix")
 	} else {
 		stop("y is of unknown type")
 	}
-	
-	
-	data$W <- as.numeric(weights)
-	
-	# sample grouping
+		
+	### weights
+	if(is.null(weights)) {
+		data$W <- rep(1/data$n.samples, data$n.samples)
+	} else if(is.vector(weights)) {
+		data$W <- as.numeric(weights)
+	} else if(is.matrix(weights)) {
+		data$W <- apply(weights, 2, as.numeric)
+	} else {
+		stop("weights is of unknown type")
+	}
+
+	### sample grouping
 	if(is.null(sampleGrouping)) {
-		sampleGrouping <- rep(1, nrow(x))
+		sampleGrouping <- rep(1, data$n.samples)
 	}
 	
 	sampleGrouping <- factor(sampleGrouping)
 	data$G <- as.integer(factor(sampleGrouping))-1L
 	
-	# group names 
+	### group names 
 	if(is.null(group.names)) {
 		data$group.names <- levels(sampleGrouping)
 	} else {
 		data$group.names <- group.names
 	}
 	
-	# dimensions
-	data$n.covariate <- ncol(x)
 	data$n.groups <- as.integer(length(data$group.names))
-		
-	# names
-	data$sample.names <- rownames(x)
-	data$covariate.names <- colnames(x)
-
-	# sparse X format
-	if(data$sparseX) {
-		data$X <- list(dim(data$X), data$X@p, data$X@i, data$X@x)
-	}
-		
+	
 	class(data) <- "sgldata"
 	return(data)
 }
@@ -171,13 +186,12 @@ create.sgldata <- function(x, y, weights = rep(1/nrow(x), nrow(x)), sampleGroupi
 #' @param alpha the \eqn{\alpha} value 0 for group lasso, 1 for lasso, between 0 and 1 gives a sparse group lasso penalty.
 #' @param ... not used
 #' @method prepare.args sgldata
-#' @S3method prepare.args sgldata
 #' @export
 #' @family sgldata
 #' @author Martin Vincent
 prepare.args.sgldata <- function(data, parameterGrouping, groupWeights, parameterWeights, alpha, ...) {
 	
-	#If Lasso then ignore grouping
+	# If Lasso then ignore grouping
 	if(alpha == 1) {
 		parameterGrouping <- factor(1:data$n.covariate)
 		groupWeights <- rep(1, data$n.covariate)
@@ -188,15 +202,26 @@ prepare.args.sgldata <- function(data, parameterGrouping, groupWeights, paramete
 		
 	group.order <- order(parameterGrouping)
 	
-	#Reorder data
+	### Reorder data
 	data <- rearrange(data, group.order)
 	
 	parameterWeights <- parameterWeights[,group.order, drop = FALSE]
-	
-	#Compute block dim
+			
+	### Compute block dim
 	block.dim <- ngrp*as.integer(table(parameterGrouping))
 	
-	#args list
+	### Prepare data format
+	# sparse X format
+	if(data$sparseX) {
+		data$X <- list(dim(data$X), data$X@p, data$X@i, data$X@x)
+	}
+	
+	# sparse Y format
+	if(data$sparseY) {
+		data$Y <- list(dim(data$Y), data$Y@p, data$Y@i, data$Y@x)
+	}
+	
+	### Create args list
 	args <- list()
 	args$block.dim <- block.dim
 	args$groupWeights <- groupWeights
