@@ -1,5 +1,9 @@
 library(sglOptim)
 
+# warnings = errors
+options(warn=2)
+
+
 data(TestData)
 x <- test.data$x
 y <- test.data$y
